.. image:: /docs/.static/pyzor.gif?raw=true
    :target: http://www.pyzor.org/
    :alt: Pyzor

Pyzor is a Python implementation of a spam-blocking networked system that use spam signatures to identify them.


.. image:: https://pypip.in/v/pyzor/badge.png
    :target: https://pypi.python.org/pypi/pyzor/
    :alt: Latest PyPI version

.. image:: https://pypip.in/d/pyzor/badge.png
    :target: https://pypi.python.org/pypi/pyzor/
    :alt: Number of PyPI downloads
    
.. image:: https://travis-ci.org/SpamExperts/pyzor.svg?branch=master
    :target: https://travis-ci.org/SpamExperts/pyzor
    :alt: Build status

.. image:: https://coveralls.io/repos/SpamExperts/pyzor/badge.png?branch=master
  :target: https://coveralls.io/r/SpamExperts/pyzor?branch=master



Quick links:

 * `Documentation <http://pyzor.readthedocs.org/>`_
 * `Download <https://pypi.python.org/pypi/pyzor/>`_
 * `Issue Tracker <https://github.com/SpamExperts/pyzor/issues>`_
 

